@@ -3,7 +3,7 @@
  *
  * https://www.msweet.org/mxml
  *
- * Copyright © 2003-2019 by Michael R Sweet.
+ * Copyright © 2003-2020 by Michael R Sweet.
  *
  * Licensed under Apache License v2.0.  See the file "LICENSE" for more
  * information.
@@ -2188,8 +2188,9 @@ mxml_parse_element(
     * Read the attribute name...
     */
 
-    name[0] = ch;
-    ptr     = name + 1;
+    ptr = name;
+    if (mxml_add_char(ch, &ptr, &name, &namesize))
+      goto error;
 
     if (ch == '\"' || ch == '\'')
     {
@@ -2249,7 +2250,7 @@ mxml_parse_element(
 
     if (mxmlElementGetAttr(node, name))
     {
-      mxml_error("Duplicate attribute '%s' in element %s on line %d.", name, node->value.element.name, name, *line);
+      mxml_error("Duplicate attribute '%s' in element %s on line %d.", name, node->value.element.name, *line);
       goto error;
     }
 
@@ -2317,8 +2318,9 @@ mxml_parse_element(
         * Read unquoted value...
 	*/
 
-	value[0] = ch;
-	ptr      = value + 1;
+	ptr      = value;
+	if (mxml_add_char(ch, &ptr, &value, &valsize))
+	  goto error;
 
 	while ((ch = (*getc_cb)(p, encoding)) != EOF)
 	{
