@@ -6,15 +6,12 @@
  *   ./testmxml input.xml [string-output.xml] >stdio-output.xml
  *   ./testmxml "<?xml ..." [string-output.xml] >stdio-output.xml
  *
- * Copyright 2003-2017 by Michael R Sweet.
+ * https://www.msweet.org/mxml
  *
- * These coded instructions, statements, and computer programs are the
- * property of Michael R Sweet and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "COPYING"
- * which should have been included with this file.  If this file is
- * missing or damaged, see the license at:
+ * Copyright © 2003-2019 by Michael R Sweet.
  *
- *     https://michaelrsweet.github.io/mxml
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more
+ * information.
  */
 
 /*
@@ -22,10 +19,10 @@
  */
 
 #include "config.h"
-#include "mxml.h"
-#ifndef WIN32
+#include "mxml-private.h"
+#ifndef _WIN32
 #  include <unistd.h>
-#endif /* !WIN32 */
+#endif /* !_WIN32 */
 #include <fcntl.h>
 #ifndef O_BINARY
 #  define O_BINARY 0
@@ -59,7 +56,8 @@ main(int  argc,				/* I - Number of command-line args */
   int			i;		/* Looping var */
   FILE			*fp;		/* File to read */
   int			fd;		/* File descriptor */
-  mxml_node_t		*tree,		/* XML tree */
+  mxml_node_t		*xml,		/* <?xml ...?> node */
+			*tree,		/* Element tree */
 			*node;		/* Node which should be in test.xml */
   mxml_index_t		*ind;		/* XML index */
   char			buffer[16384];	/* Save string */
@@ -87,7 +85,8 @@ main(int  argc,				/* I - Number of command-line args */
   * Test the basic functionality...
   */
 
-  tree = mxmlNewElement(MXML_NO_PARENT, "element");
+  xml  = mxmlNewXML("1.0");
+  tree = mxmlNewElement(xml, "element");
 
   if (!tree)
   {
@@ -127,6 +126,22 @@ main(int  argc,				/* I - Number of command-line args */
                  MXML_OPAQUE_CALLBACK);
   mxmlLoadString(tree, "<foo><bar><one><two>value<two>value2</two></two></one>"
                        "</bar></foo>", MXML_OPAQUE_CALLBACK);
+  mxmlNewCDATA(tree,
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n");
+  mxmlNewCDATA(tree,
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n");
+  mxmlNewCDATA(tree,
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n"
+               "0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef\n");
 
   node = tree->child;
 
@@ -313,10 +328,10 @@ main(int  argc,				/* I - Number of command-line args */
     return (1);
   }
 
-  if (ind->num_nodes != 10)
+  if (ind->num_nodes != 13)
   {
     fprintf(stderr, "ERROR: Index of all nodes contains %d "
-                    "nodes; expected 10.\n", ind->num_nodes);
+                    "nodes; expected 13.\n", ind->num_nodes);
     mxmlIndexDelete(ind);
     mxmlDelete(tree);
     return (1);
@@ -421,7 +436,7 @@ main(int  argc,				/* I - Number of command-line args */
   * Check the mxmlDelete() works properly...
   */
 
-  for (i = 0; i < 9; i ++)
+  for (i = 0; i < 12; i ++)
   {
     if (tree->child)
       mxmlDelete(tree->child);
@@ -446,14 +461,14 @@ main(int  argc,				/* I - Number of command-line args */
     return (1);
   }
 
-  mxmlDelete(tree);
+  mxmlDelete(xml);
 
  /*
   * Open the file/string using the default (MXML_NO_CALLBACK) callback...
   */
 
   if (argv[1][0] == '<')
-    tree = mxmlLoadString(NULL, argv[1], MXML_NO_CALLBACK);
+    xml = mxmlLoadString(NULL, argv[1], MXML_NO_CALLBACK);
   else if ((fp = fopen(argv[1], "rb")) == NULL)
   {
     perror(argv[1]);
@@ -465,12 +480,12 @@ main(int  argc,				/* I - Number of command-line args */
     * Read the file...
     */
 
-    tree = mxmlLoadFile(NULL, fp, MXML_NO_CALLBACK);
+    xml = mxmlLoadFile(NULL, fp, MXML_NO_CALLBACK);
 
     fclose(fp);
   }
 
-  if (!tree)
+  if (!xml)
   {
     fputs("Unable to read XML file with default callback.\n", stderr);
     return (1);
@@ -485,7 +500,7 @@ main(int  argc,				/* I - Number of command-line args */
     * properly...
     */
 
-    if ((node = mxmlFindPath(tree, "group/option/keyword")) == NULL)
+    if ((node = mxmlFindPath(xml, "group/option/keyword")) == NULL)
     {
       fputs("Unable to find group/option/keyword element in XML tree.\n", stderr);
       mxmlDelete(tree);
@@ -495,27 +510,27 @@ main(int  argc,				/* I - Number of command-line args */
     if (node->type != MXML_TEXT)
     {
       fputs("No child node of group/option/keyword.\n", stderr);
-      mxmlSaveFile(tree, stderr, MXML_NO_CALLBACK);
-      mxmlDelete(tree);
+      mxmlSaveFile(xml, stderr, MXML_NO_CALLBACK);
+      mxmlDelete(xml);
       return (1);
     }
 
     if ((text = mxmlGetText(node, NULL)) == NULL || strcmp(text, "InputSlot"))
     {
       fprintf(stderr, "Child node of group/option/value has value \"%s\" instead of \"InputSlot\".\n", text ? text : "(null)");
-      mxmlDelete(tree);
+      mxmlDelete(xml);
       return (1);
     }
   }
 
-  mxmlDelete(tree);
+  mxmlDelete(xml);
 
  /*
   * Open the file...
   */
 
   if (argv[1][0] == '<')
-    tree = mxmlLoadString(NULL, argv[1], type_cb);
+    xml = mxmlLoadString(NULL, argv[1], type_cb);
   else if ((fp = fopen(argv[1], "rb")) == NULL)
   {
     perror(argv[1]);
@@ -527,12 +542,12 @@ main(int  argc,				/* I - Number of command-line args */
     * Read the file...
     */
 
-    tree = mxmlLoadFile(NULL, fp, type_cb);
+    xml = mxmlLoadFile(NULL, fp, type_cb);
 
     fclose(fp);
   }
 
-  if (!tree)
+  if (!xml)
   {
     fputs("Unable to read XML file.\n", stderr);
     return (1);
@@ -545,7 +560,7 @@ main(int  argc,				/* I - Number of command-line args */
     * properly...
     */
 
-    if ((node = mxmlFindElement(tree, tree, "choice", NULL, NULL,
+    if ((node = mxmlFindElement(xml, xml, "choice", NULL, NULL,
                                 MXML_DESCEND)) == NULL)
     {
       fputs("Unable to find first <choice> element in XML tree.\n", stderr);
@@ -553,7 +568,7 @@ main(int  argc,				/* I - Number of command-line args */
       return (1);
     }
 
-    if (!mxmlFindElement(node, tree, "choice", NULL, NULL, MXML_NO_DESCEND))
+    if (!mxmlFindElement(node, xml, "choice", NULL, NULL, MXML_NO_DESCEND))
     {
       fputs("Unable to find second <choice> element in XML tree.\n", stderr);
       mxmlDelete(tree);
@@ -565,13 +580,13 @@ main(int  argc,				/* I - Number of command-line args */
   * Print the XML tree...
   */
 
-  mxmlSaveFile(tree, stdout, whitespace_cb);
+  mxmlSaveFile(xml, stdout, whitespace_cb);
 
  /*
   * Save the XML tree to a string and print it...
   */
 
-  if (mxmlSaveString(tree, buffer, sizeof(buffer), whitespace_cb) > 0)
+  if (mxmlSaveString(xml, buffer, sizeof(buffer), whitespace_cb) > 0)
   {
     if (argc == 3)
     {
@@ -585,7 +600,7 @@ main(int  argc,				/* I - Number of command-line args */
   * Delete the tree...
   */
 
-  mxmlDelete(tree);
+  mxmlDelete(xml);
 
  /*
   * Read from/write to file descriptors...
@@ -607,7 +622,7 @@ main(int  argc,				/* I - Number of command-line args */
     * Read the file...
     */
 
-    tree = mxmlLoadFd(NULL, fd, type_cb);
+    xml = mxmlLoadFd(NULL, fd, type_cb);
 
     close(fd);
 
@@ -628,7 +643,7 @@ main(int  argc,				/* I - Number of command-line args */
     * Write the file...
     */
 
-    mxmlSaveFd(tree, fd, whitespace_cb);
+    mxmlSaveFd(xml, fd, whitespace_cb);
 
     close(fd);
 
@@ -636,7 +651,7 @@ main(int  argc,				/* I - Number of command-line args */
     * Delete the tree...
     */
 
-    mxmlDelete(tree);
+    mxmlDelete(xml);
   }
 
  /*
@@ -679,9 +694,9 @@ main(int  argc,				/* I - Number of command-line args */
       return (1);
     }
 
-    if (event_counts[MXML_SAX_DATA] != 60)
+    if (event_counts[MXML_SAX_DATA] != 61)
     {
-      fprintf(stderr, "MXML_SAX_DATA seen %d times, expected 60 times.\n",
+      fprintf(stderr, "MXML_SAX_DATA seen %d times, expected 61 times.\n",
               event_counts[MXML_SAX_DATA]);
       return (1);
     }
@@ -708,7 +723,7 @@ main(int  argc,				/* I - Number of command-line args */
     }
   }
 
-#ifndef WIN32
+#ifndef _WIN32
  /*
   * Debug hooks...
   */
@@ -725,7 +740,7 @@ main(int  argc,				/* I - Number of command-line args */
       puts("Unable to check for leaks.");
   }
 #  endif /* __APPLE__ */
-#endif /* !WIN32 */
+#endif /* !_WIN32 */
 
  /*
   * Return...
